@@ -22,6 +22,7 @@ package utils
 import (
 	"github.com/mitchellh/mapstructure"
 	"golang.org/x/exp/constraints"
+	"strconv"
 )
 
 func SetDefaultNum[K constraints.Integer | constraints.Float](p *K, d K) {
@@ -30,6 +31,18 @@ func SetDefaultNum[K constraints.Integer | constraints.Float](p *K, d K) {
 	}
 }
 
+func SetDefaultUnsignNum[K constraints.Integer | constraints.Float](p *K, d K) {
+	if *p <= 0 {
+		*p = d
+	}
+}
+
+func SetDefaultString(p *string, d string) {
+	if len(*p) == 0 {
+		*p = d
+	}
+}
+
 func CheckNumRange[K constraints.Integer | constraints.Float](v, min, max K) bool {
 	if v < min || v > max {
 		return false
@@ -38,7 +51,7 @@ func CheckNumRange[K constraints.Integer | constraints.Float](v, min, max K) boo
 }
 
 // WeakDecode decodes args from config to output.
-func WeakDecode(in map[string]interface{}, output interface{}) error {
+func WeakDecode(in any, output any) error {
 	config := &mapstructure.DecoderConfig{
 		ErrorUnused:      true,
 		Result:           output,
@@ -53,3 +66,12 @@ func WeakDecode(in map[string]interface{}, output interface{}) error {
 
 	return decoder.Decode(in)
 }
+
+func ParseNameOrNum[T constraints.Integer](s string, m map[string]T) (T, bool) {
+	i, err := strconv.Atoi(s)
+	if err != nil {
+		v, ok := m[s]
+		return v, ok
+	}
+	return T(i), true
+}
