@@ -21,21 +21,23 @@ package server_utils
 
 import (
 	"fmt"
+
 	"github.com/IrineSistiana/mosdns/v5/coremain"
-	"github.com/IrineSistiana/mosdns/v5/pkg/server/dns_handler"
+	"github.com/IrineSistiana/mosdns/v5/pkg/server"
+	"github.com/IrineSistiana/mosdns/v5/pkg/server_handler"
 	"github.com/IrineSistiana/mosdns/v5/plugin/executable/sequence"
 )
 
-func NewHandler(bp *coremain.BP, entry string) (dns_handler.Handler, error) {
+func NewHandler(bp *coremain.BP, entry string) (server.Handler, error) {
 	p := bp.M().GetPlugin(entry)
 	exec := sequence.ToExecutable(p)
 	if exec == nil {
 		return nil, fmt.Errorf("cannot find executable entry by tag %s", entry)
 	}
 
-	handlerOpts := dns_handler.EntryHandlerOpts{
+	handlerOpts := server_handler.EntryHandlerOpts{
 		Logger: bp.L(),
 		Entry:  exec,
 	}
-	return dns_handler.NewEntryHandler(handlerOpts), nil
+	return server_handler.NewEntryHandler(handlerOpts), nil
 }
